@@ -28,7 +28,6 @@
 import gtk 
 import gobject
 import hildon
-import sys
 import pygame
 from time import strftime
 from datetime import datetime, timedelta
@@ -38,7 +37,7 @@ from portrait import FremantleRotation
 STOPWATCH = 1
 COUNTDOWN = 2
 
-class StopwatchApp(hildon.Program):
+class NS(hildon.Program):
     def __init__(self):
         hildon.Program.__init__(self)
         
@@ -488,5 +487,5 @@ class StopwatchApp(hildon.Program):
 
 
 if __name__ == "__main__":  
-    app = StopwatchApp() 
+    app = NS() 
     app.run()         
